#
# spec file for package libgeos
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 1
%define major 3
%define minor 4
%define micro 2
%define pkg_name geos
#See: https://en.opensuse.org/openSUSE:Shared_library_packaging_policy

Name:           libgeos
Version:        3.4.2
Release:        2.4
Summary:        Geometry Engine - Open Source
License:        LGPL-2.1
Group:          Productivity/Scientific/Other
Url:            http://trac.osgeo.org/geos/
Source0:        %{pkg_name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM incorrect-fsf-address.patch avvissu@yandex.ru -- Fix wrong fsf address
Patch0:         incorrect-fsf-address.patch
# PATCH-FIX-OPENSUSE date_and_time.patch avvissu@yandex.ru -- Do not compile in DATE and TIME
Patch1:         date_and_time.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Packager:      Otto Dassau <dassau@gbd-consult.de>

%description
GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology
Suite (JTS). As such, it aims to contain the complete functionality of
JTS in C++. This includes all the OpenGIS "Simple Features for SQL" spatial
predicate functions and spatial operators, as well as specific JTS topology
functions such as IsValid()

%package -n %{name}-%{major}_%{minor}_%{micro}
Summary:        Libraries for GEOS
License:        LGPL-2.1
Group:          System/Libraries

%description -n %{name}-%{major}_%{minor}_%{micro}
GEOS (Geometry Engine - Open Source) is a C++ port of the Java Topology
Suite (JTS). As such, it aims to contain the complete functionality of
JTS in C++. This includes all the OpenGIS "Simple Features for SQL" spatial
predicate functions and spatial operators, as well as specific JTS topology
functions such as IsValid()

%package -n %{name}_c%{soname}
Summary:        Libraries for GEOS
License:        LGPL-2.1
Group:          System/Libraries
Provides:       %{pkg_name} = %{version}
Provides:       %{name} = %{version}
Provides:       %{name}%{soname} = %{version}

%description -n %{name}_c%{soname}
API library is called  directly from Python using ctypes.

%package devel
Summary:        Development files for GEOS
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Requires:       %{name}-%{major}_%{minor}_%{micro} = %{version}
Requires:       %{name}_c%{soname} = %{version}
Provides:       %{pkg_name}-devel = %{version}
Obsoletes:      %{pkg_name}-devel < %{version}

%description devel
This package contains the development files to build applications that
use GEOS.

%if 0%{?suse_version} > 1140 
%package doc
Summary:        Documentation for GEOS
Group:          Documentation/HTML
Provides:       %{pkg_name} = %{version}
Obsoletes:      %{pkg_name} < %{version}
BuildArch:      noarch

%description doc
API Documentation for GEOS.
%endif

%prep
%setup -q -D -n geos-%{version}
%patch0 -p1
%patch1 -p1

%build
%configure --prefix=%{_prefix} \
           --enable-static=no \
           --disable-dependency-tracking

make %{?_smp_mflags}
pushd doc
make doxygen-html %{?_smp_mflags}
popd

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

mkdir -p %{buildroot}%{_docdir}/%{name}-%{major}_%{minor}_%{micro}/API
mv doc/doxygen_docs/html %{buildroot}%{_docdir}/%{name}-%{major}_%{minor}_%{micro}/API

%fdupes -s %{buildroot}%{_docdir}/%{name}-%{major}_%{minor}_%{micro}

%check
make %{?_smp_mflags} check || :

%post -n  %{name}-%{major}_%{minor}_%{micro} -p /sbin/ldconfig

%postun -n  %{name}-%{major}_%{minor}_%{micro} -p /sbin/ldconfig

%post -n %{name}_c%{soname} -p /sbin/ldconfig

%postun -n %{name}_c%{soname} -p /sbin/ldconfig

%files -n %{name}-%{major}_%{minor}_%{micro}
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README TODO
%{_libdir}/%{name}-%{version}.so
%exclude %{_docdir}/%{name}-%{major}_%{minor}_%{micro}/API

%files -n %{name}_c%{soname}
%defattr(-,root,root)
%{_libdir}/%{name}_c.*%{soname}*

%files devel
%defattr(-,root,root)
%{_bindir}/%{pkg_name}-config
%{_includedir}/%{pkg_name}*
%{_libdir}/%{name}.so
%{_libdir}/%{name}_c.so
%exclude %{_libdir}/%{name}*.la

%if 0%{?suse_version} > 1140 
%files doc
%defattr(-,root,root)
%{_docdir}/%{name}-%{major}_%{minor}_%{micro}/API
%endif

%changelog
* Wed Nov 19 2014 avvissu@yandex.ru
- Do not compile in DATE and TIME (date_and_time.patch)
* Wed Oct  8 2014 avvissu@yandex.ru
- Update to 3.4.2 (Initial release - Adapted spec-file to openSUSE
  according to the shared library packaging policy)
- Completely rewritten spec-file for building RPM
- Removed changelog from spec file
- add libgeos.changes file in project
- Changed the spec file through spec-cleaner
- add API Documentation
- add baselibs.conf to support "bi-arch" distributions
